@@ -25,6 +25,7 @@ from .client import Client
 from .grpc_client.connection import insecure_grpc_connection
 from .grpc_client.message_handler import handle
 from .keras_client import KerasClient, KerasClientWrapper
+from .numpy_client import NumPyClient, NumPyClientWrapper
 
 
 def start_client(
@@ -44,9 +45,9 @@ def start_client(
             The maximum length of gRPC messages that can be exchanged with the
             Flower server. The default should be sufficient for most models.
             Users who train very large models might need to increase this
-            value. Note that the Flower server needs to started with the same
-            value (see `flwr.server.start_server`), otherwise it will not know
-            about the increased limit and block larger messages.
+            value. Note that the Flower server needs to be started with the
+            same value (see `flwr.server.start_server`), otherwise it will not
+            know about the increased limit and block larger messages.
 
     Returns:
         None.
@@ -79,6 +80,42 @@ def start_client(
         time.sleep(sleep_duration)
 
 
+def start_numpy_client(
+    server_address: str,
+    client: NumPyClient,
+    grpc_max_message_length: int = GRPC_MAX_MESSAGE_LENGTH,
+) -> None:
+    """Start a Flower NumPyClient which connects to a gRPC server.
+
+    Arguments:
+        server_address: str. The IPv6 address of the server. If the Flower
+            server runs on the same machine on port 8080, then `server_address`
+            would be `"[::]:8080"`.
+        client: flwr.client.NumPyClient. An implementation of the abstract base
+            class `flwr.client.NumPyClient`.
+        grpc_max_message_length: int (default: 536_870_912, this equals 512MB).
+            The maximum length of gRPC messages that can be exchanged with the
+            Flower server. The default should be sufficient for most models.
+            Users who train very large models might need to increase this
+            value. Note that the Flower server needs to be started with the
+            same value (see `flwr.server.start_server`), otherwise it will not
+            know about the increased limit and block larger messages.
+
+    Returns:
+        None.
+    """
+
+    # Wrap the NumPyClient
+    flower_client = NumPyClientWrapper(client)
+
+    # Start
+    start_client(
+        server_address=server_address,
+        client=flower_client,
+        grpc_max_message_length=grpc_max_message_length,
+    )
+
+
 def start_keras_client(
     server_address: str,
     client: KerasClient,
@@ -96,9 +133,9 @@ def start_keras_client(
             The maximum length of gRPC messages that can be exchanged with the
             Flower server. The default should be sufficient for most models.
             Users who train very large models might need to increase this
-            value. Note that the Flower server needs to started with the same
-            value (see `flwr.server.start_server`), otherwise it will not know
-            about the increased limit and block larger messages.
+            value. Note that the Flower server needs to be started with the
+            same value (see `flwr.server.start_server`), otherwise it will not
+            know about the increased limit and block larger messages.
 
     Returns:
         None.
