@@ -18,6 +18,7 @@
 from .default import DefaultStrategy as DefaultStrategy
 from .fast_and_slow import FastAndSlow as FastAndSlow
 from .fault_tolerant_fedavg import FaultTolerantFedAvg as FaultTolerantFedAvg
+from .fedadagrad import FedAdagrad as FedAdagrad
 from .fedavg import FedAvg as FedAvg
 from .fedfs_v0 import FedFSv0 as FedFSv0
 from .fedfs_v1 import FedFSv1 as FedFSv1
@@ -28,6 +29,7 @@ __all__ = [
     "DefaultStrategy",
     "FastAndSlow",
     "FaultTolerantFedAvg",
+    "FedAdagrad",
     "FedAvg",
     "FedFSv0",
     "FedFSv1",
