@@ -25,6 +25,7 @@ from flwr.common import (
     EvaluateRes,
     FitIns,
     FitRes,
+    Scalar,
     Weights,
     parameters_to_weights,
     weights_to_parameters,
@@ -56,8 +57,8 @@ class FedFSv0(FedAvg):
         eval_fn: Optional[Callable[[Weights], Optional[Tuple[float, float]]]] = None,
         min_completion_rate_fit: float = 0.5,
         min_completion_rate_evaluate: float = 0.5,
-        on_fit_config_fn: Optional[Callable[[int], Dict[str, str]]] = None,
-        on_evaluate_config_fn: Optional[Callable[[int], Dict[str, str]]] = None,
+        on_fit_config_fn: Optional[Callable[[int], Dict[str, Scalar]]] = None,
+        on_evaluate_config_fn: Optional[Callable[[int], Dict[str, Scalar]]] = None,
         r_fast: int = 1,
         r_slow: int = 1,
         t_fast: int = 10,
@@ -186,6 +187,7 @@ class FedFSv0(FedAvg):
         # Track contributions to the global model
         for client, fit_res in results:
             cid = client.cid
+            assert fit_res.num_examples_ceil is not None
             contribution: Tuple[int, int, int] = (
                 rnd,
                 fit_res.num_examples,
