@@ -161,7 +161,7 @@ class ImageNetClient(fl.client.Client):
 
         # Return the number of evaluation examples and the evaluation result (loss)
         return fl.common.EvaluateRes(
-            num_examples=len(self.testset), loss=float(loss), accuracy=float(accuracy)
+            loss=float(loss), num_examples=len(self.testset), accuracy=float(accuracy)
         )
 
 
