@@ -14,15 +14,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
+
 set -e
-cd "$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"/../../../
+
 SERVER_ADDRESS="[::]:8080"
 NUM_CLIENTS=2
-I_START=0
-I_END=${NUM_CLIENTS}
 
 echo "Starting $NUM_CLIENTS clients."
-for ((i = $I_START; i < $I_END; i++))
+for ((i = 0; i < $NUM_CLIENTS; i++))
 do
     echo "Starting client(cid=$i) with partition $i out of $NUM_CLIENTS clients."
     python -m flwr_example.quickstart_pytorch.client \
