@@ -21,8 +21,5 @@ from .common import get_eval_fn as get_eval_fn
 from .common import get_lr_schedule as get_lr_schedule
 from .common import keras_evaluate as keras_evaluate
 from .common import keras_fit as keras_fit
-from .config import configure_client_instances as configure_client_instances
-from .config import sample_delay_factors as sample_delay_factors
-from .config import sample_real_delay_factors as sample_real_delay_factors
 from .data import build_dataset as build_dataset
 from .data import load_partition as load_partition
