@@ -12,4 +12,5 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
-"""Provides various adapters with standard interface to make compute resources available."""
+"""Provides various adapters with standard interface to make compute resources
+available."""
